bootstrap.BootstrapSession

|  | ## Cheshire3 Object Model: Class BootstrapSession

Module bootstrap :: Class BootstrapSession

## Class BootstrapSession
source code

Instance Methods

__init__(self)

Class Variables

user |
inHandler |
outHandler |

Method Details

### __init__(self) (Constructor) | source code

Class Variable Details

    ### user Value:
        None

    ### inHandler Value:
        None

    ### outHandler Value:
        None